# lambdata
Python package for DS


This is a simple example package created by Henry Gultom as an 
assignment for Data Science class.
The package is about:

1. Conversion of State_abbreviation (sample: FL to Florida, and vice versa)
2. date conversion to: year, month, and day

    sample of date dataframe: 
    df = pd.DataFrame({'date': ['2018-08-09 11:10:55','2019-03-02 13:15:21']})


My test.pypi is on:
https://test.pypi.org/project/lambdata-henry/
  